@@ -5,8 +5,8 @@
 #include "krbookmarkhandler.h"
 
 class KrBookmarkButton: public TQToolButton {
-	Q_OBJECT
-  TQ_OBJECT
+	TQ_OBJECT
+  
 public:
 	KrBookmarkButton(TQWidget *parent);
 	void openPopup();
@@ -18,7 +18,7 @@ protected slots:
 	void populate();
 	
 private:
-	KActionMenu *acmBookmarks;
+	TDEActionMenu *acmBookmarks;
 };
 
 #endif // KRBOOKMARK_BUTTON_H
