@@ -37,7 +37,7 @@
 class PercentalSplitterToolTip;
 
 class PercentalSplitter : public TQSplitter {
-  Q_OBJECT
+  TQ_OBJECT
   
   
 public:
