@@ -33,13 +33,13 @@
 #include "../defaults.h"
 #include "../Dialogs/krdialogs.h"
 #include <tqtabwidget.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqwhatsthis.h>
 #include <tqvalidator.h>
 #include <tqlistview.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
+#include <tdemessagebox.h>
+#include <tdefiledialog.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include "../Panel/krselectionmode.h"
 #include "../Panel/listpanel.h"
@@ -107,7 +107,7 @@ void KgLookFeel::setupOperationTab() {
 
   quicksearchCheckboxes = createCheckBoxGroup( 2, 0, quicksearch, 2 /*count*/, quicksearchGroup, 0, PAGE_OPERATION );
   quicksearchGrid->addWidget( quicksearchCheckboxes, 0, 0 );
-  connect( quicksearchCheckboxes->find( "New Style Quicksearch" ), TQT_SIGNAL( stateChanged( int ) ), this, TQT_SLOT( slotDisable() ) );
+  connect( quicksearchCheckboxes->find( "New Style Quicksearch" ), TQ_SIGNAL( stateChanged( int ) ), this, TQ_SLOT( slotDisable() ) );
   slotDisable();
 
   lookAndFeelLayout->addWidget( quicksearchGroup, 1, 0 );
@@ -141,7 +141,7 @@ void KgLookFeel::setupPanelTab() {
      { i18n( "32" ),  "32" },
      { i18n( "48" ),  "48" }};
   KonfiguratorComboBox *iconCombo = createComboBox( "Look&Feel", "Filelist Icon Size", _FilelistIconSize, iconSizes, 4, hbox2, true, true, PAGE_PANEL );
-  iconCombo->lineEdit()->setValidator( new TQRegExpValidator( TQRegExp( "[1-9]\\d{0,1}" ), TQT_TQOBJECT(iconCombo) ) );
+  iconCombo->lineEdit()->setValidator( new TQRegExpValidator( TQRegExp( "[1-9]\\d{0,1}" ), iconCombo ) );
   createSpacer ( hbox2 );
   panelGrid->addWidget( hbox2, 1, 0 );
 
@@ -197,7 +197,7 @@ void KgLookFeel::setupPanelToolbarTab() {
   };
 
   panelToolbarActive = createCheckBoxGroup( 1, 0, panelToolbarActiveCheckbox, 1, tab_4, "panelToolbarActive", PAGE_PANELTOOLBAR);
-  connect( panelToolbarActive->find( "Panel Toolbar visible" ), TQT_SIGNAL( stateChanged( int ) ), this, TQT_SLOT( slotEnablePanelToolbar() ) );
+  connect( panelToolbarActive->find( "Panel Toolbar visible" ), TQ_SIGNAL( stateChanged( int ) ), this, TQ_SLOT( slotEnablePanelToolbar() ) );
     
   TQGroupBox * panelToolbarGrp = createFrame( i18n( "Visible Panel Toolbar buttons" ), tab_4, "panelToolbarGrp");
   TQGridLayout * panelToolbarGrid = createGridLayout( panelToolbarGrp->layout() );
@@ -253,7 +253,7 @@ void KgLookFeel::setupMouseModeTab() {
   mouseRadio = createRadioButtonGroup( "Look&Feel", "Mouse Selection", "0", 2, 2, mouseSelection, 4, mouseGeneralGroup, "myLook&FeelRadio", true, PAGE_MOUSE );
   mouseRadio->layout()->setMargin( 0 );
   mouseGeneralGrid->addWidget( mouseRadio, 0, 0 );
-  connect( mouseRadio, TQT_SIGNAL( clicked(int) ), TQT_SLOT( slotSelectionModeChanged() ) );
+  connect( mouseRadio, TQ_SIGNAL( clicked(int) ), TQ_SLOT( slotSelectionModeChanged() ) );
 
   mouseLayout->addMultiCellWidget( mouseGeneralGroup, 0,0, 0,1 );
 
@@ -267,7 +267,7 @@ void KgLookFeel::setupMouseModeTab() {
     {
     	//          name            value            tooltip
     	{ i18n( "Double-click selects (classic)" ), "0", i18n( "A single click on a file will select and focus, a double click opens the file or steps into the directory." ) },
-    	{ i18n( "Obey KDE's global selection policy" ), "1", i18n( "<p>Use KDE's global setting:</p><p><i>KDE Control Center -> Peripherals -> Mouse</i></p>" ) }
+    	{ i18n( "Obey TDE's global selection policy" ), "1", i18n( "<p>Use TDE's global setting:</p><p><i>Trinity Control Center -> Peripherals -> Mouse</i></p>" ) }
     };
   KonfiguratorRadioButtons *clickRadio = createRadioButtonGroup( "Look&Feel", "Single Click Selects", "0", 1, 0, singleOrDoubleClick, 2, mouseDetailGroup, "myLook&FeelRadio0", true, PAGE_MOUSE );
   clickRadio->layout()->setMargin( 0 );
@@ -278,9 +278,9 @@ void KgLookFeel::setupMouseModeTab() {
      // {cfg_class,   cfg_name,   default
      // 	text,  restart,
      // 	tooltip }
-     {"Custom Selection Mode",  "QT Selection",  _TQtSelection,
-     	i18n( "Based on KDE's selection mode" ), true,
-     	i18n( "If checked, use a mode based on KDE's style." ) },
+     {"Custom Selection Mode",  "TQt Selection",  _TQtSelection,
+     	i18n( "Based on TDE's selection mode" ), true,
+     	i18n( "If checked, use a mode based on TDE's style." ) },
      {"Custom Selection Mode",  "Left Selects",  _LeftSelects,
      	i18n( "Left mouse button selects" ), true,
      	i18n( "If checked, left clicking an item will select it." ) },
@@ -352,7 +352,7 @@ void KgLookFeel::slotEnablePanelToolbar()
 
 void KgLookFeel::slotSelectionModeChanged() {
   bool enable = mouseRadio->find( i18n("Custom Selection Mode") )->isChecked();
-  mouseCheckboxes->find( "QT Selection" )->setEnabled( enable );
+  mouseCheckboxes->find( "TQt Selection" )->setEnabled( enable );
   mouseCheckboxes->find( "Left Selects" )->setEnabled( enable );
   mouseCheckboxes->find( "Left Preserves" )->setEnabled( enable );
   mouseCheckboxes->find( "ShiftCtrl Left Selects" )->setEnabled( enable );
