@@ -54,7 +54,7 @@ class KRdirWatch;
 class fsData;
 
 class KMountManGUI : public KDialogBase {
-   Q_OBJECT
+   TQ_OBJECT
   
 
    enum Pages {
