@@ -18,12 +18,12 @@ email                :
 #ifndef USERMENU_H
 #define USERMENU_H
 
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 class TQWidget;
 class UserMenu;
 
-class UserMenuGui: public KPopupMenu {
+class UserMenuGui: public TDEPopupMenu {
    public:
       UserMenuGui( UserMenu* menu, TQWidget *parent = 0 );
       void run();
